@@ -11,7 +11,7 @@ searchword - german example: S for Stuttgart.
 
 Copyright (C) 2010 Patrick Beck <pbeck at yourse dot de>  
 
-I have to thanks Bartholomäus Wloka for the created austrian and poland country package
+Thanks to all contributors :) A list is in the README file :)
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -109,6 +109,7 @@ class KFZcheck(QMainWindow):
                     self.listfield_list.append(i)
                     self.addItemstoList('%s, %s' % (i[0], i[1])) # when only 2 values in the csv files
         
+            self.ui.searchfield.show() # when no csv file found at the first start and you change the country - the searchfield should be displayed
         except:
             self.addItemstoList(self.tr("csv file not found or has not enough rights."))
             self.ui.searchfield.hide() # no searchoption - the message will be stay on the screen
